/* 
   Copyright (C) 2009 Dejan Lozanovic realnull at gmail dot com

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
package org.elitesecurity.shape;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Polygon;
import java.awt.Rectangle;

import javax.swing.JButton;


public class GenericShapeComponent extends JButton {
	public GenericShapeComponent() {
	}
	private static final long serialVersionUID = -3267748690438495628L;
	
	private Shape shape;
	private Color color;
	private Polygon polygon;
	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paint(java.awt.Graphics)
	 */
	@Override
	public void paint(Graphics g) {
//		super.paint(g);
		if(shape!=null) {
			if(color!=null) {
				g.setColor(color);
			}
			try {
				Rectangle rectangle = getClipBounds(g);
				polygon = shape.drawShape(rectangle, g);
			} catch (Exception e) {
				super.paint(g);
			}
		}
	}

	private Rectangle getClipBounds(Graphics g) {
		Rectangle r = g.getClipBounds();
		int length = Math.min(r.height, r.width);
		
		// get center position 
		int x = (r.width-length) / 2;
		int y = (r.height-length) /2;
		
		return new Rectangle(x,y,length,length);
	}

	/**
	 * @return the shape
	 */
	public Shape getShape() {
		return shape;
	}

	/**
	 * @param shape the shape to set
	 */
	public void setShape(Shape shape) {
		this.shape = shape;
		repaint();
	}

	/**
	 * @return the color
	 */
	public Color getColor() {
		return color;
	}

	/**
	 * @param color the color to set
	 */
	public void setColor(Color color) {
		this.color = color;
		repaint();
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#contains(int, int)
	 */
	@Override
	public boolean contains(int x, int y) {
		if(polygon!=null) {
			return polygon.contains(x, y);
		}else {
			return super.contains(x, y);
		}
	}
	
	
}
