/* 
   Copyright (C) 2009 Dejan Lozanovic realnull at gmail dot com

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
package org.elitesecurity.shape;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;
import java.util.ArrayList;
import java.util.Random;

import javax.sound.sampled.AudioInputStream;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JOptionPane;

import org.elitesecurity.utils.PlayAudio;
import org.elitesecurity.utils.SwingUtils;

import com.jgoodies.forms.factories.FormFactory;
import com.jgoodies.forms.layout.ColumnSpec;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.RowSpec;
import javax.swing.ImageIcon;


public class ShapeDialog extends JDialog {
	private static final long serialVersionUID = 3704984054629604292L;
	private GenericShapeComponent[] components;
	private Shape[] shapes;
	private Random random = new Random(System.currentTimeMillis());
	
	private GenericShapeComponent testComponent;
	private JButton btnIzlaz;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		try {
			ShapeDialog dialog = new ShapeDialog();
			dialog.setDefaultCloseOperation(JDialog.HIDE_ON_CLOSE);
			dialog.setVisible(true);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Create the dialog.
	 */
	public ShapeDialog() {
		// Now generate shapes
		shapes = new Shape[6];
		shapes[0] = new Circle();
		shapes[1] = new Triangle();
		shapes[2] = new Square();
		shapes[3] = new Rectangle();
		shapes[4] = new Rhomb();
		shapes[5] = new Pentagon();

		getContentPane().setLayout(new FormLayout(new ColumnSpec[] {
				FormFactory.RELATED_GAP_COLSPEC,
				ColumnSpec.decode("default:grow(2)"),
				FormFactory.RELATED_GAP_COLSPEC,
				ColumnSpec.decode("default:grow(3)"),
				FormFactory.RELATED_GAP_COLSPEC,
				FormFactory.DEFAULT_COLSPEC,
				FormFactory.RELATED_GAP_COLSPEC,},
			new RowSpec[] {
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,
				RowSpec.decode("fill:default:grow"),
				FormFactory.RELATED_GAP_ROWSPEC,}));
//		getContentPane().setBackground(Color.WHITE);
		SwingUtils.setFullScreen(this);
		
		components = new GenericShapeComponent[6];
		for (int i = 0; i < components.length; i++) {
			components[i]=new GenericShapeComponent();
			components[i].setColor(Color.BLACK);
			components[i].addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					performDetection(e);
				}
			});
		}
		
		getContentPane().add(components[0], "2, 2");
		getContentPane().add(components[1], "2, 4");
		getContentPane().add(components[2], "2, 6");
		getContentPane().add(components[3], "2, 8");
		getContentPane().add(components[4], "2, 10");
		getContentPane().add(components[5], "2, 12");

		URL url = ShapeDialog.class.getResource("/picture/exit.jpg");
		btnIzlaz = new JButton(new ImageIcon(url));
		btnIzlaz.setBorderPainted(false);
		btnIzlaz.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				System.exit(0);
			}
		});
			testComponent = new GenericShapeComponent();
			testComponent.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
				}
			});
			testComponent.setShape(new Circle());
			testComponent.setColor(Color.BLACK);
			getContentPane().add(testComponent, "4, 2, 3, 7, fill, fill");
			
		getContentPane().add(btnIzlaz, "6, 10, 1, 3, default, bottom");
		
		shuffle();
	}

	private void shuffle() {
		testComponent.setShape(shapes[random.nextInt(shapes.length)]);
		
		ArrayList<Shape> shapeSet = new ArrayList<Shape>(shapes.length);
		for (int i = 0; i < shapes.length; i++) {
			shapeSet.add(shapes[i]);
		}
		
		
		for (int i = 0; i < components.length; i++) {
			int idx = random.nextInt(shapeSet.size());
			Shape shape = shapeSet.remove(idx);
			components[i].setShape(shape);
		}
		
		repaint();
	}
	
	private void performDetection(ActionEvent e) {
		Object o = e.getSource();
		if(o instanceof GenericShapeComponent) {
			GenericShapeComponent button = (GenericShapeComponent)o;
			if(button.getShape().getClass().equals(testComponent.getShape().getClass())) {
				URL url = ShapeDialog.class.getResource("/audio/aplauz-1.wav");
				new PlayAudio(url).start();
				shuffle();
			} else {
				URL url = ShapeDialog.class.getResource("/audio/razmisli.wav");
				new PlayAudio(url).start();
			}
		}
	}

}
